Microsoft Translator API for Python
-----------------------------------

The *Microsoft* offers an online translation API to make requests
through various forms (Http, Ajax, SOAP or OData.). The features
provided by this API are very useful when we want to perform
translations, multiple translations or even listen to the pronunciation
of a certain word or phrase in desejada.Esta language library is an
implementation in Python that allows to use most of the features present
in this API. Basically what we do is, make a request to the Ajax API
method by **requests** module and get the desired response. Below is a
list of features offered by this library:

-  Translation of one or multiple phrases and texts.
-  Obtaining all possible translations for a word or multiple phrases.
-  So speak, where you can hear the pronunciation of phrases or text in
   the desired language.
-  This language detection on single or multiple sentences or texts.
-  Obtaining all possible languages for translation and so speak.

SEE ON GITHUB: https://github.com/dookgulliver/BingTranslator

License
~~~~~~~

Microsoft Translator API for Python

Copyright (c) 2014, Will Filho, All rights reserved.

This library is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 3.0 of the License, or (at
your option) any later version.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this library.
